{% extends "base.html" %}
{% block title %}Page not found - {% endblock %}
{% block content %}
<article class="post post__full">
	<h2 class="mp-title title">Page not found</h2>
    <div class="micropress-post entry-content">
		<p>
			Page not found.
		</p>
	</div>
</article>
{% endblock %}
